@@ -183,16 +183,12 @@ class Client(Wss, Session):
         chatType: int = 0,
     ):
 
-        if type(userId) is list:
-            userIds = userId
-        elif type(userId) is str:
-            userIds = [userId]
-        else:
-            raise TypeError("Please put a str or list of userId")
+        if isinstance(userId, str):
+            userId = [userId]
 
         data = {
             "title": title,
-            "inviteeUids": userIds,
+            "inviteeUids": userId,
             "initialMessageContent": message,
             "content": content,
             "type": chatType,
@@ -200,7 +196,7 @@ class Client(Wss, Session):
         }
 
         req = self.postRequest(f"/g/s/chat/thread", data)
-        return Json(req)
+        return Thread(req).Thread
 
     def get_from_link(self, link: str):
         req = self.getRequest(f"/g/s/link-resolution?q={link}")
@@ -313,13 +309,11 @@ class Client(Wss, Session):
     def follow(self, userId: Union[str, list]):
         data = {"timestamp": int(timestamp() * 1000)}
 
-        if type(userId) is str:
+        if isinstance(userId, str):
             link = f"/g/s/user-profile/{userId}/member"
-        elif type(userId) is list:
+        elif isinstance(userId, list):
             data["targetUidList"] = userId
             link = f"/g/s/user-profile/{self.uid}/joined"
-        else:
-            raise TypeError("Please put a str or list of userId")
 
         req = self.postRequest(link, data)
         return Json(req)
@@ -414,13 +408,13 @@ class Client(Wss, Session):
 
         mentions = []
         if mentionUserIds:
-            if type(mentionUserIds) is list:
+            if isinstance(mentionUserIds, list):
                 for mention_uid in mentionUserIds:
                     mentions.append({"uid": mention_uid})
             mentions.append({"uid": mentionUserIds})
 
         if embedImage:
-            if type(embedImage) is not str:
+            if not isinstance(embedImage, str):
                 embedImage = [[100, self.upload_image(embedImage), None]]
             embedImage = [[100, embedImage, None]]
 
