@@ -157,13 +157,13 @@ class Local(Session):
 
         mentions = []
         if mentionUserIds:
-            if type(mentionUserIds) is list:
+            if isinstance(mentionUserIds, list):
                 for mention_uid in mentionUserIds:
                     mentions.append({"uid": mention_uid})
             mentions.append({"uid": mentionUserIds})
 
         if embedImage:
-            if type(embedImage) is not str:
+            if not isinstance(embedImage, str):
                 embedImage = [[100, self.upload_image(embedImage, "image"), None]]
             embedImage = [[100, embedImage, None]]
 
@@ -274,13 +274,11 @@ class Local(Session):
     def follow(self, userId: Union[str, list]):
         data = {"timestamp": int(timestamp() * 1000)}
 
-        if type(userId) is str:
+        if isinstance(userId, str):
             link = f"/x{self.comId}/s/user-profile/{userId}/member"
-        elif type(userId) is list:
+        elif isinstance(userId, list):
             link = f"/x{self.comId}/s/user-profile/{self.uid}/joined"
             data["targetUidList"] = userId
-        else:
-            raise TypeError("Please put str or list of userId")
 
         req = self.postRequest(link, data)
         return Json(req)
@@ -293,16 +291,12 @@ class Local(Session):
         content: str = None,
         chatType: int = 0,
     ):
-        if type(userId) is str:
-            userIds = userId
-        elif type(userId) is list:
-            userIds = [userId]
-        else:
-            raise TypeError("Please put a str or list of userId")
+        if isinstance(userId, str):
+            userId = [userId]
 
         data = {
             "title": title,
-            "inviteeUids": userIds,
+            "inviteeUids": userId,
             "initialMessageContent": message,
             "content": content,
             "type": chatType,
@@ -310,17 +304,13 @@ class Local(Session):
         }
 
         req = self.postRequest(f"/x{self.comId}/s/chat/thread", data)
-        return Json(req)
+        return Thread(req['thread']).Thread
 
     def invite_to_chat(self, userId: Union[str, list], chatId: str = None):
-        if type(userId) is str:
-            userIds = [userId]
-        elif type(userId) is list:
-            userIds = userId
-        else:
-            raise TypeError("Please put a str or list of userId")
+        if isinstance(userId, str):
+            userId = [userId]
 
-        data = {"uids": userIds, "timestamp": int(timestamp() * 1000)}
+        data = {"uids": userId, "timestamp": int(timestamp() * 1000)}
 
         req = self.postRequest(
             f"/x{self.comId}/s/chat/thread/{chatId}/member/invite", data=data
